**********
User Guide
**********

Welcome to the Ansible User Guide!

This guide covers how to work with Ansible, including using the command line, working with inventory, and writing playbooks.  

.. toctree::
   :maxdepth: 2
  
   quickstart
   intro_getting_started
   command_line_tools
   intro_adhoc
   intro_inventory
   intro_dynamic_inventory
   playbooks
   become
   vault
   intro_patterns
   modules
   ../plugins/plugins
   intro_bsd
   windows



